@@ -1,5 +1,5 @@
 package File::Dir::Dumper::DigestCache::Dummy;
-$File::Dir::Dumper::DigestCache::Dummy::VERSION = '0.6.2';
+$File::Dir::Dumper::DigestCache::Dummy::VERSION = '0.6.3';
 use warnings;
 use strict;
 
@@ -38,7 +38,7 @@ L<File::Dir::Dumper> .
 
 =head1 VERSION
 
-version 0.6.2
+version 0.6.3
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-dir-dumper/issues>
+L<https://github.com/shlomif/perl-File-Dir-Dumper/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
