@@ -1,5 +1,5 @@
 package File::Dir::Dumper::Scanner;
-$File::Dir::Dumper::Scanner::VERSION = '0.6.2';
+$File::Dir::Dumper::Scanner::VERSION = '0.6.3';
 use warnings;
 use strict;
 use autodie;
@@ -335,7 +335,7 @@ hash-refs
 
 =head1 VERSION
 
-version 0.6.2
+version 0.6.3
 
 =head1 SYNOPSIS
 
@@ -451,7 +451,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-dir-dumper/issues>
+L<https://github.com/shlomif/perl-File-Dir-Dumper/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
